[Bf-blender-cvs] SVN commit: /data/svn/bf-blender [59969] trunk/blender: Usual UI messages fixes...

Bastien Montagne montagne29 at wanadoo.fr
Mon Sep 9 22:22:02 CEST 2013


Revision: 59969
          http://projects.blender.org/scm/viewvc.php?view=rev&root=bf-blender&revision=59969
Author:   mont29
Date:     2013-09-09 20:22:01 +0000 (Mon, 09 Sep 2013)
Log Message:
-----------
Usual UI messages fixes...

Modified Paths:
--------------
    trunk/blender/release/scripts/modules/bl_i18n_utils/utils_spell_check.py
    trunk/blender/source/blender/editors/mesh/editmesh_bisect.c
    trunk/blender/source/blender/makesrna/intern/rna_color.c
    trunk/blender/source/blender/makesrna/intern/rna_object_force.c
    trunk/blender/source/blender/makesrna/intern/rna_ui.c
    trunk/blender/source/blender/windowmanager/intern/wm_event_system.c

Modified: trunk/blender/release/scripts/modules/bl_i18n_utils/utils_spell_check.py
===================================================================
--- trunk/blender/release/scripts/modules/bl_i18n_utils/utils_spell_check.py	2013-09-09 20:13:39 UTC (rev 59968)
+++ trunk/blender/release/scripts/modules/bl_i18n_utils/utils_spell_check.py	2013-09-09 20:22:01 UTC (rev 59969)
@@ -71,6 +71,7 @@
         "backscattered",
         "bandnoise",
         "bindcode",
+        "bitflag", "bitflags",
         "bitrate",
         "blackbody",
         "blendfile",
@@ -432,6 +433,7 @@
         "catrom",
         "chebychev",
         "courant",
+        "hosek",
         "kutta",
         "lennard",
         "minkowski",
@@ -440,10 +442,12 @@
         "nayar",
         "netravali",
         "oren",
+        "preetham",
         "prewitt",
         "runge",
         "sobol",
         "verlet",
+        "wilkie",
         "worley",
 
         # Acronyms

Modified: trunk/blender/source/blender/editors/mesh/editmesh_bisect.c
===================================================================
--- trunk/blender/source/blender/makesrna/intern/rna_color.c	2013-09-09 20:13:39 UTC (rev 59968)
+++ trunk/blender/source/blender/makesrna/intern/rna_color.c	2013-09-09 20:22:01 UTC (rev 59969)
@@ -980,7 +980,7 @@
 	};
 
 	static EnumPropertyItem look_items[] = {
-		{0, "NONE", 0, "None", "Do not modify image in an artistics manner"},
+		{0, "NONE", 0, "None", "Do not modify image in an artistic manner"},
 		{0, NULL, 0, NULL, NULL}
 	};
 
@@ -1015,7 +1015,7 @@
 	RNA_def_property_enum_funcs(prop, "rna_ColorManagedViewSettings_look_get",
 	                                  "rna_ColorManagedViewSettings_look_set",
 	                                  "rna_ColorManagedViewSettings_look_itemf");
-	RNA_def_property_ui_text(prop, "Look", "Additional tarnsform applyed before view transform for an artistics needs");
+	RNA_def_property_ui_text(prop, "Look", "Additional transform applied before view transform for an artistic needs");
 	RNA_def_property_update(prop, NC_WINDOW, "rna_ColorManagement_update");
 
 	prop = RNA_def_property(srna, "view_transform", PROP_ENUM, PROP_NONE);

Modified: trunk/blender/source/blender/makesrna/intern/rna_object_force.c
===================================================================
--- trunk/blender/source/blender/makesrna/intern/rna_object_force.c	2013-09-09 20:13:39 UTC (rev 59968)
+++ trunk/blender/source/blender/makesrna/intern/rna_object_force.c	2013-09-09 20:22:01 UTC (rev 59969)
@@ -862,8 +862,8 @@
 	prop = RNA_def_property(srna, "use_library_path", PROP_BOOLEAN, PROP_NONE);
 	RNA_def_property_boolean_negative_sdna(prop, NULL, "flag", PTCACHE_IGNORE_LIBPATH);
 	RNA_def_property_ui_text(prop, "Library Path",
-	                         "Use this files path for the disk cache when library linked into another file. "
-	                         "For local bakes per scene file, disable this option");
+	                         "Use this file's path for the disk cache when library linked into another file "
+	                         "(for local bakes per scene file, disable this option)");
 	RNA_def_property_update(prop, NC_OBJECT, "rna_Cache_idname_change");
 
 	prop = RNA_def_property(srna, "point_caches", PROP_COLLECTION, PROP_NONE);

Modified: trunk/blender/source/blender/makesrna/intern/rna_ui.c
===================================================================
--- trunk/blender/source/blender/makesrna/intern/rna_ui.c	2013-09-09 20:13:39 UTC (rev 59968)
+++ trunk/blender/source/blender/makesrna/intern/rna_ui.c	2013-09-09 20:22:01 UTC (rev 59969)
@@ -1122,7 +1122,7 @@
 
 	prop = RNA_def_property(srna, "bitflag_filter_item", PROP_INT, PROP_UNSIGNED);
 	RNA_def_property_ui_text(prop, "FILTER_ITEM",
-	                               "The value of the reserved bitfalg 'FILTER_ITEM' (in filter_flags values)");
+	                               "The value of the reserved bitflag 'FILTER_ITEM' (in filter_flags values)");
 	RNA_def_property_int_funcs(prop, "rna_UIList_filter_const_FILTER_ITEM_get", NULL, NULL);
 	RNA_def_property_clear_flag(prop, PROP_EDITABLE);
 }

Modified: trunk/blender/source/blender/windowmanager/intern/wm_event_system.c
===================================================================
--- trunk/blender/source/blender/windowmanager/intern/wm_event_system.c	2013-09-09 20:13:39 UTC (rev 59968)
+++ trunk/blender/source/blender/windowmanager/intern/wm_event_system.c	2013-09-09 20:22:01 UTC (rev 59969)
@@ -1121,7 +1121,7 @@
 				/* window is needed for invoke, cancel operator */
 				if (window == NULL) {
 					if (poll_only) {
-						CTX_wm_operator_poll_msg_set(C, "missing 'window' in context");
+						CTX_wm_operator_poll_msg_set(C, "Missing 'window' in context");
 					}
 					return 0;
 				}




More information about the Bf-blender-cvs mailing list
--- trunk/blender/source/blender/editors/mesh/editmesh_bisect.c	2013-09-09 20:13:39 UTC (rev 59968)
+++ trunk/blender/source/blender/editors/mesh/editmesh_bisect.c	2013-09-09 20:22:01 UTC (rev 59969)
@@ -78,7 +78,7 @@
 	int x_end = RNA_int_get(op->ptr, "xend");
 	int y_end = RNA_int_get(op->ptr, "yend");
 
 	/* reference location (some point infront of the view) for finding a point on a plane */
 	const float *co_ref = rv3d->ofs;
 	float co_a_ss[2] = {x_start, y_start}, co_b_ss[2] = {x_end, y_end}, co_delta_ss[2];
 	float co_a[3], co_b[3];
@@ -323,7 +323,7 @@
 
 	RNA_def_boolean(ot->srna, "use_fill", false, "Fill", "Fill in the cut");
 	RNA_def_boolean(ot->srna, "clear_inner", false, "Clear Inner", "Remove geometry behind the plane");
-	RNA_def_boolean(ot->srna, "clear_outer", false, "Clear Outer", "Remove geometry infront of the plane");
+	RNA_def_boolean(ot->srna, "clear_outer", false, "Clear Outer", "Remove geometry in front of the plane");
 
 	RNA_def_float(ot->srna, "threshold", 0.0001, 0.0, 10.0, "Axis Threshold", "", 0.00001, 0.1);
 
@@ -78,7 +78,7 @@
 	int y_end = RNA_int_get(op->ptr, "yend");
 
-	/* reference location (some point infront of the view) for finding a point on a plane */
+	/* reference location (some point in front of the view) for finding a point on a plane */
 	const float *co_ref = rv3d->ofs;
 	float co_a_ss[2] = {x_start, y_start}, co_b_ss[2] = {x_end, y_end}, co_delta_ss[2];

Modified: trunk/blender/source/blender/makesrna/intern/rna_color.c
===================================================================